translate.misc.ini.EmptyLine

Package translate :: Package misc :: Module ini :: Class EmptyLine |
[hide private]
[frames] | no frames]

# Class EmptyLine

source code

Instance Methods | [hide private]
to_string(self) | source code
Inherited from `LineType`: `__init__`, `__setattr__`, `__str__` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`

Class Methods | [hide private]
parse(cls, line) | source code

Class Variables | [hide private]
Inherited from `LineType`: `line`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### to_string(self) | source code
Overrides: LineType.to_string